declare module ezmp {

    /**
     * 初始化
     * @param options 初始化选项
     */
    function init(options: zTypeInitOptions): Promise<any>;
    /**
     * 准备好了
     */
    function onReady(): Promise<any>;
    /**
     * 获取配置信息
     * @param  key 配置KEY
     * @param  def 默认值
     */
    function getConfig(key?: string, def?: any): any;
    /**
     * 监听小游戏回到前台的事件
     * @param callback 回调
     */
    function onShow(callback: (options: zOnShowOptions) => void): void;
    /**
     * 取消监听小游戏回到前台的事件
     * @param callback 回调
     */
    function offShow(callback: (options: zOnShowOptions) => void): void;
    /**
     * 监听小游戏隐藏到后台事件
     * @param callback 回调
     */
    function onHide(callback: () => void): void;
    /**
     * 取消监听小游戏隐藏到后台事件
     * @param callback 回调
     */
    function offHide(callback: () => void): void;
    /**
     * 获取UserID
     */
    function getUserId(): string;
    /**
     * 获取OpenID
     */
    function getOpenId(): string;
    /**
     * 获取SessionID
     */
    function getSessionId(): string;

    /**  接口模块 */
    module api {
        /**
         * GET请求接口
         * @param path 接口路径
         * @param query 请求参数
         * @param header 请求头
         * @param waitLogin 是否等待登录成功后请求
         */
        function getApi(path: string, query?: zTypeObject, header?: zTypeObject, waitLogin?: boolean): Promise<zTypeApiRes<any>>;
        /**
         * POST请求接口
         * @param path 接口路径
         * @param body 请求参数
         * @param header 请求头
         * @param waitLogin 是否等待登录成功后请求
         */
        function postApi(path: string, body: zTypeObject, header?: zTypeObject, waitLogin?: boolean): Promise<zTypeApiRes<any>>;
        /**
         * 获取应用信息
         */
        function getAppInfo(): Promise<zTypeApiRes<any>>;
        /**
         * 获取服务器时间
         */
        function getServerTime(): Promise<zTypeApiRes<any>>;
        /**
         * 上传用户信息
         * @param info 用户信息
         */
        function setUserInfo(info: zTypeObject): Promise<zTypeApiRes<any>>;
        /**
         * 获取用户信息
         */
        function getUserInfo(): Promise<zTypeApiRes<any>>;
        /**
         * 设置用户托管数据
         * @param kv_data_list eg:[{key:'key1',value:'value1'}]
         */
        function setUserData(kv_data_list: zTypeApiKV[]): Promise<zTypeApiRes<any>>;
        /**
         * 获取用户托管数据
         * @param key_list eg:['key1']
         */
        function getUserData(key_list: string[]): Promise<zTypeApiRes<zTypeApiKV[]>>;
        /**
         * 移除用户托管数据
         * @param key_list eg:['key1']
         */
        function removeUserData(key_list: string[]): Promise<zTypeApiRes<any>>;
        /**
         * 获取世界排行榜列表
         * @param key KEY
         * @param page 页码
         * @param size 每页数量
         */
        function getRankList(key: string, page?: number, size?: number): Promise<zTypeApiRes<any>>;
        /**
         * 获取好友列表
         */
        function getFriendList(): Promise<zTypeApiRes<any>>;
        /**
         * 添加好友
         * @param friend_id 好友用户ID
         */
        function addFriend(friend_id: string): Promise<zTypeApiRes<any>>;
        /**
         * 删除好友
         * @param friend_id 好友用户ID
         */
        function removeFriend(friend_id: string): Promise<zTypeApiRes<any>>;
        /**
         * 获取用户消息列表
         */
        function getMessageList(): Promise<zTypeApiRes<any>>;
        /**
         * 发送用户消息
         * @param user_id 用户id
         * @param content 消息内容
         */
        function postMessage(user_id: string, content: string): Promise<zTypeApiRes<any>>;
        /**
         * 将消息设置为已读
         * @param id_list 消息id列表
         */
        function flushMessage(id_list: string[]): Promise<zTypeApiRes<any>>;
        /**
         * 解密微信加密数据
         * @param encryptedData 密文
         * @param iv 加密偏移向量
         */
        function decryptWechatData(encryptedData: string, iv: string): Promise<zTypeApiRes<any>>;
    }

    /** 资源模块 */
    module asset {
        /**
         * 获取文件地址
         * @param path 资源路径
         */
        function url(path): string;
        /**
         * 获取资源内容
         * @param path 资源路径
         * @param cacheExpires 缓存有效时间
         */
        function fetch(path: string, cacheExpires?: number): Promise<any>;
    }

    /** 关卡模块 */
    module level {
        /**
         * 获取关卡列表信息
         * @param parentId 父类ID
         * @param cacheExpires 缓存有效时间
         */
        function getLevelList(parentId?: string, cacheExpires?: number): Promise<any>;
    }

    /** 设置模块 */
    module setting {
        /**
         * 获取任务信息
         * @param cacheExpires 缓存有效时间
         */
        function getTaskSetting(cacheExpires?: number): Promise<zTypeSettingTask[]>;
        /**
         * 获取分享配置列表
         * @param cacheExpires 缓存有效时间
         */
        function getShareSetting(cacheExpires?: number): Promise<zTypeSettingShare[]>;
        /**
         * 获取推荐应用列表
         * @param cacheExpires 缓存有效时间
         */
        function getRecommendSetting(cacheExpires?: number): Promise<zTypeSettingRecommend[]>;
        /**
         * 获取自定义配置
         * @param title 自定义配置KEY
         * @param defaultValue 默认值
         * @param cacheExpires 缓存有效时间
         */
        function getCustomSetting(title, defaultValue?: any, cacheExpires?: number): Promise<any>;
        /**
         * 检查是否为线上版本
         * @param currentVersion 当前版本
         * @param title 用于验证的自定义配置KEY，默认：version
         */
        function isVersionOnline(currentVersion: string, title?: string): Promise<boolean>;
    }

    /**  数据模块 */
    module data {
        /**
         * 设置数据
         * @param key 
         * @param value
         * @param onlyNotExists
         */
        function set(key: string, value: any, onlyNotExists?: boolean): void;
        /**
         * 获取数据
         * @param key 
         * @param defValue
         */
        function get(key: string, defValue?: any): any;
        /**
         * 移除数据
         * @param key 
         */
        function remove(key: string): void;
        /**
         * 获取key列表
         */
        function keys(): string[]
        /**
         * 是否存在数据
         * @param key
         */
        function has(key: string): boolean;
        /**
         * 清空数据
         */
        function clear(): void;
    }

    /** 转发分享 */
    module share {
        /** 分享 */
        function shareAsync(options?: zTypeShareOptions): Promise<any>;
    }

    /**
     * 每周签到模块
     */
    module weekly {
        /**
         * 签到状态枚举
         */
        enum Status {
            ERROR = -3,
            FUTURE_UN_SIGNIN = -2,
            BYGONE_UN_SIGNIN = -1,
            TODAY_UN_SIGNIN = 0,
            TODAY_SIGNIN = 1,
            BYGONE_SIGNIN = 2,
        }
        /**
         * 签到或补签
         * @param day 
         */
        function checkin(day: number): Promise<boolean>;
        /**
         * 获取签到状态
         * @param day
         */
        function getStatus(day: number): Promise<Status>;
    }

    /**
     * 环境检测模块
     */
    module env {
        /**
         * 环境枚举
         */
        enum Platform {
            FB = 'facebook',
            QQ = 'qq',
            WX = 'wechat',
            BD = 'baidu',
            BR = 'browser'
        }
        /**
         * 是否是Browser环境
         */
        function isBrowserApp(): boolean;
        /**
         * 是否为QQ环境
         */
        function isQQApp(): boolean;
        /**
         * 是否为Facebook环境
         */
        function isFacebookApp(): boolean;
        /**
         * 是否为Wechat环境
         */
        function isWechatApp(): boolean;
        /**
         * 是否为Baidu环境
         */
        function isBaiduApp(): boolean;
        /**
         * 获取当前环境
         */
        function getPlatform(): Platform;
        /**
         * 获取SDK名称
         */
        function getSDKName(): string;
        /**
         * 获取SDK版本号
         */
        function getSDKVersion(): string;
    }

    /**  工具类 */
    module utils {
        /**
         * 任意类型转换
         * @param value
         * @param def 
         */
        function toAny(value: any, def: any): any;
        /**
         * 字符串BASE64加密
         * @param input 
         */
        function encodeBase64(input: string): string;
        /**
         * 字符串BASE64解密
         * @param input
         */
        function decodeBase64(input: string): string;
        /**
         * 生成随机GUID
         */
        function randomGUID(): string;
        /**
         * 解析Query参数
         * @param path 
         */
        function parseQueryParams(path: string): { url: string, params: zTypeObject };
        /**
         * 追加Query参数
         * @param path 
         * @param query
         */
        function appendQueryParams(path: string, query: zTypeObject): void;
    }

}